==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/SectionFooterDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { SectionFooterDescription } from "./SectionFooterDescription";
/**
 * @hidden
 */
export let SectionFooterDescriptionMetadata = /*@__PURE__*/ (() => {
    class SectionFooterDescriptionMetadata extends Base {
        static b(a) {
            if (SectionFooterDescriptionMetadata.a == null) {
                SectionFooterDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SectionFooterDescriptionMetadata.c(SectionFooterDescriptionMetadata.a);
            }
            if (a.k(SectionFooterDescriptionMetadata.a)) {
                return;
            }
            a.ab(SectionFooterDescriptionMetadata.a);
        }
        static c(a) {
            DefinitionBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            SectionFooterDescriptionMetadata.b(a);
            a.ad("SectionFooter", () => new SectionFooterDescription());
            a.ac("SectionFooter", SectionFooterDescriptionMetadata.a);
        }
    }
    SectionFooterDescriptionMetadata.$t = markType(SectionFooterDescriptionMetadata, 'SectionFooterDescriptionMetadata');
    SectionFooterDescriptionMetadata.a = null;
    return SectionFooterDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/SectionFooterDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { SectionFooterDescription } from "./SectionFooterDescription";
/**
 * @hidden
 */
export let SectionFooterDescriptionMetadata = /*@__PURE__*/ (() => {
    class SectionFooterDescriptionMetadata extends Base {
        static b(a) {
            if (SectionFooterDescriptionMetadata.a == null) {
                SectionFooterDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SectionFooterDescriptionMetadata.c(SectionFooterDescriptionMetadata.a);
            }
            if (a.k(SectionFooterDescriptionMetadata.a)) {
                return;
            }
            a.ac(SectionFooterDescriptionMetadata.a);
        }
        static c(a) {
            DefinitionBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            SectionFooterDescriptionMetadata.b(a);
            a.ae("SectionFooter", () => new SectionFooterDescription());
            a.ad("SectionFooter", SectionFooterDescriptionMetadata.a);
        }
    }
    SectionFooterDescriptionMetadata.$t = markType(SectionFooterDescriptionMetadata, 'SectionFooterDescriptionMetadata');
    SectionFooterDescriptionMetadata.a = null;
    return SectionFooterDescriptionMetadata;
})();
